@@ -112,17 +112,23 @@ def probability(factory, n_samples, test, conditional_on=None):
         * Or a tuple of such factories (cf. examples below).
     n_samples : int
         Number of samples.
-    test : callable
-        A function that take as input(s) the output(s) of the factory(ies) and that returns a Boolean.
+    test : callable or tuple
+        This can be:
+
+        * Either a function that take as input(s) the output(s) of the factory(ies) and that returns a Boolean.
+        * Or a tuple of such functions (cf. examples below).
     conditional_on : callable
         A function that take as input(s) the output(s) of the factory(ies) and that returns a Boolean.
         Default: always True.
 
     Returns
     -------
-    float
-        The probability that the output(s) generated by `factory` meet(s) `test`, conditional on the fact
-        that it meets `conditional_on`, based on a Monte-Carlo estimation of `n_samples` trials.
+    float or tuple
+        This can be:
+
+        * Either the probability that the output(s) generated by `factory` meet(s) `test`, conditional on the fact
+          that it meets `conditional_on`, based on a Monte-Carlo estimation of `n_samples` trials.
+        * Either a tuple giving this probability for each member of `test`, when `test` is a tuple itself.
 
     Examples
     --------
@@ -152,18 +158,38 @@ def probability(factory, n_samples, test, conditional_on=None):
         >>> probability(factory=(rand_matrix, rand_vector), n_samples=10000,
         ...             test=test_dot_zero, conditional_on=test_non_trivial)
         0.0003
+
+    In the following example, we estimate the probability that a random float between 0 and 1 is greater than .5,
+    and the probability that it is greater than .75, conditionally on being greater than .25:
+
+        >>> initialize_random_seeds()
+        >>> def rand_number():
+        ...     return random.random()
+        >>> probability(factory=rand_number, n_samples=1000,
+        ...             test=(lambda x: x > .5, lambda x: x > .75), conditional_on=lambda x: x > .25)
+        (0.661, 0.332)
+
+    When using a tuple of tests, the same samples are used to estimate each probability.
     """
     if not isinstance(factory, tuple):
         factory = (factory,)
-    success = 0
+    is_test_tuple = isinstance(test, tuple)
+    if not is_test_tuple:
+        test = (test,)
+    l_test_success = [0 for the_test in test]
     i_samples = 0
     while i_samples < n_samples:
-        somethings = [g() for g in factory]
+        somethings = [f() for f in factory]
         if conditional_on is None or conditional_on(*somethings):
             i_samples += 1
-            if test(*somethings):
-                success += 1
-    return success / n_samples
+            for i_test, the_test in enumerate(test):
+                if the_test(*somethings):
+                    l_test_success[i_test] += 1
+    l_test_rate = [successes / n_samples for successes in l_test_success]
+    if is_test_tuple:
+        return tuple(l_test_rate)
+    else:
+        return l_test_rate[0]
 
 
 def image_distribution(factory, n_samples, f, conditional_on=None):
