@@ -1,5 +1,5 @@
-from poisson_approval.profiles.ProfileOrdinal import ProfileOrdinal
-from poisson_approval.strategies.StrategyOrdinal import StrategyOrdinal
+from fractions import Fraction
+from poisson_approval import ProfileOrdinal, StrategyOrdinal, ProfileDiscrete, StrategyThreshold
 
 
 def test():
@@ -17,6 +17,8 @@ def test():
     {a: 7/10, b: 3/5, c: 3/10}
     >>> print(strategy.winners)
     a
+    >>> strategy.share_sincere
+    >>> strategy.share_sincere_among_strategic_voters
     >>> strategy.duo_ab
     <asymptotic = exp(- 0.1 n + o(1)), phi_a = 0, phi_c = 1, phi_ab = 1>
     >>> strategy.duo_ba
@@ -171,3 +173,23 @@ phi_ab = 0.707107>
     EquilibriumStatus.EQUILIBRIUM
     """
     pass
+
+
+def test_shares():
+    """
+        >>> profile = ProfileDiscrete({
+        ...     ('abc', Fraction(2, 11)): 1,  # Sincere vote: a
+        ... }, ratio_fanatic=Fraction(1, 3))
+        >>> strategy = StrategyOrdinal({'abc': 'ab'}, profile=profile)
+        >>> strategy.tau
+        TauVector({'a': Fraction(1, 3), 'ab': Fraction(2, 3)})
+        >>> strategy.share_single_votes
+        Fraction(1, 3)
+        >>> strategy.share_double_votes
+        Fraction(2, 3)
+        >>> strategy.share_sincere_among_strategic_voters
+        0
+        >>> strategy.share_sincere
+        Fraction(1, 3)
+    """
+    pass
